<?php
/**
 * swedish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Per Foreby <per@foreby.se>
 * @author Nicklas Henriksson <nicklas[at]nihe.se>
 * @author Håkan Sandell <hakan.sandell[at]mydata.se>
 * @author Dennis Karlsson
 * @author Tormod Otter Johansson <tormod@latast.se>
 * @author emil@sys.nu
 * @author Pontus Bergendahl <pontus.bergendahl@gmail.com>
 */
$lang['menu']                  = 'Hantera insticksmoduler';
$lang['download']              = 'Ladda ned och installera en ny insticksmodul';
$lang['manage']                = 'Installerade insticksmoduler';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'uppdatera';
$lang['btn_delete']            = 'radera';
$lang['btn_settings']          = 'inställningar';
$lang['btn_download']          = 'Ladda ned';
$lang['btn_enable']            = 'Spara';
$lang['url']                   = 'Webbadress';
$lang['installed']             = 'Installerad:';
$lang['lastupdate']            = 'Senast uppdaterad:';
$lang['source']                = 'Källa:';
$lang['unknown']               = 'okänd';
$lang['updating']              = 'Uppdaterar ...';
$lang['updated']               = 'Insticksmodulen %s uppdaterades';
$lang['updates']               = 'Följande Insticksmoduler har uppdaterats';
$lang['update_none']           = 'Inga uppdateringar hittades.';
$lang['deleting']              = 'Raderar ...';
$lang['deleted']               = 'Insticksmodulen %s raderad.';
$lang['downloading']           = 'Laddar ned ...';
$lang['downloaded']            = 'Insticksmodulen %s installerades';
$lang['downloads']             = 'Följande insticksmoduler har installerats:';
$lang['download_none']         = 'Inga insticksmoduler hittades, eller så har det uppstått ett okänt fel under nedladdning och installation.';
$lang['plugin']                = 'Insticksmodul:';
$lang['components']            = 'Komponenter';
$lang['noinfo']                = 'Den här insticksmodulen returnerade ingen information, den kan vara ogiltig.';
$lang['name']                  = 'Namn:';
$lang['date']                  = 'Datum:';
$lang['type']                  = 'Typ:';
$lang['desc']                  = 'Beskrivning:';
$lang['author']                = 'Författare:';
$lang['www']                   = 'Webb:';
$lang['error']                 = 'Ett okänt fel har inträffat.';
$lang['error_download']        = 'Kan inte ladda ned fil till insticksmodul: %s';
$lang['error_badurl']          = 'Misstänkt felaktig webbadress - kan inte bestämma filnamnet från webbadressen';
$lang['error_dircreate']       = 'Kan inte skapa tillfällig katalog för nedladdade filer';
$lang['error_decompress']      = 'Hanteraren för insticksmoduler kunde inte dekomprimera den nedladdade filen. Detta kan vara resultatet av en misslyckad nedladdning, och i så fall bör du försöka igen; eller så kan det komprimerade formatet vara okänt, och då måste du ladda ned och installera insticksmodulen manuellt.';
$lang['error_copy']            = 'Ett filkopieringsfel uppstod under försöket att installera filerna till insticksmodulen <em>%s</em>: disken kan vara full eller så kan filskyddet vara felaktigt. Detta kan ha lett till en delvis installerad insticksmodul, och gjort din wiki-installation instabil.';
$lang['error_delete']          = 'Ett fel uppstod vid försöket att radera insticksmodulen <em>%s</em>.  Den troligaste orsaken är otillräcklig behörighet till filer eller kataloger';
$lang['enabled']               = 'Tilläggsmodulen %s är aktiverad.';
$lang['notenabled']            = 'Tilläggsmodulen %s kunde inte aktiveras, kontrollera filrättigheterna.';
$lang['disabled']              = 'Tiläggsmodulen %s är avaktiverad.';
$lang['notdisabled']           = 'Tilläggsmodulen %s kunde inte avaktiveras, kontrollera filrättigheterna.';
